==> flink-1.13.6-src.tgz: flink-1.13.6/flink-connectors/flink-connector-kafka/src/test/java/org/apache/flink/connector/kafka/source/KafkaSourceTestUtils.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.connector.kafka.source;

import org.apache.flink.api.connector.source.SourceReaderContext;
import org.apache.flink.connector.kafka.source.reader.KafkaSourceReader;

import java.util.Collection;
import java.util.function.Consumer;

/** Utility class for testing {@link KafkaSource}. */
public class KafkaSourceTestUtils {

    /**
     * Create {@link KafkaSourceReader} with a custom hook handling IDs of finished {@link
     * org.apache.flink.connector.kafka.source.split.KafkaPartitionSplit}.
     *
     * @param kafkaSource Kafka source
     * @param sourceReaderContext Context for SourceReader
     * @param splitFinishedHook Hook for handling finished splits
     * @param <T> Type of emitting records
     */
    public static <T> KafkaSourceReader<T> createReaderWithFinishedSplitHook(
            KafkaSource<T> kafkaSource,
            SourceReaderContext sourceReaderContext,
            Consumer<Collection<String>> splitFinishedHook)
            throws Exception {
        return ((KafkaSourceReader<T>)
                kafkaSource.createReader(sourceReaderContext, splitFinishedHook));
    }
}

==> flink-1.14.6-src.tgz: flink-1.14.6/flink-connectors/flink-connector-kafka/src/test/java/org/apache/flink/connector/kafka/source/KafkaSourceTestUtils.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.connector.kafka.source;

import org.apache.flink.api.connector.source.SourceReaderContext;
import org.apache.flink.configuration.Configuration;
import org.apache.flink.connector.kafka.source.reader.KafkaSourceReader;

import java.util.Collection;
import java.util.function.Consumer;

/** Utility class for testing {@link KafkaSource}. */
public class KafkaSourceTestUtils {

    /**
     * Create {@link KafkaSourceReader} with a custom hook handling IDs of finished {@link
     * org.apache.flink.connector.kafka.source.split.KafkaPartitionSplit}.
     *
     * @param kafkaSource Kafka source
     * @param sourceReaderContext Context for SourceReader
     * @param splitFinishedHook Hook for handling finished splits
     * @param <T> Type of emitting records
     */
    public static <T> KafkaSourceReader<T> createReaderWithFinishedSplitHook(
            KafkaSource<T> kafkaSource,
            SourceReaderContext sourceReaderContext,
            Consumer<Collection<String>> splitFinishedHook)
            throws Exception {
        return ((KafkaSourceReader<T>)
                kafkaSource.createReader(sourceReaderContext, splitFinishedHook));
    }

    /** Get configuration of KafkaSource. */
    public static Configuration getKafkaSourceConfiguration(KafkaSource<?> kafkaSource) {
        return kafkaSource.getConfiguration();
    }
}
